
COURSES_BASE_URL = "https://nikel.ml/api/courses?"

PROGRAMS_BASE_URL = "https://nikel.ml/api/programs?"

TEXTBOOKS_BASE_URL = "https://nikel.ml/api/textbooks?"

EXAMS_BASE_URL = "https://nikel.ml/api/exams?"

EVALS_BASE_URL = "https://nikel.ml/api/evals?"

FOOD_BASE_URL = "https://nikel.ml/api/food?"

SERVICES_BASE_URL = "https://nikel.ml/api/services?"

BUILDINGS_BASE_URL = "https://nikel.ml/api/buildings?"

PARKING_BASE_URL = "https://nikel.ml/api/parking?"